@@ -1,10 +1,5 @@
 from .command import Command
-
-from .constant import (
-    Constant,
-    SpinValue,
-)
-
+from .constant import Constant
 from .register import Register
 
 from .status import (
